``imbalanced_ensemble.ensemble``
*********************************

This is the full API documentation of the `imbalanced_ensemble.ensemble` module.

.. toctree::
   :maxdepth: 3

   under-sampling
   over-sampling
   reweighting
   compatible